Start Romagna
Description: Start, la nuova grande realtà del trasporto pubblico in Romagna.

# Registrati

# Entra nel mondo Start e usufruisci di tanti vantaggi.

Gli utenti registrati Start hanno un accesso dedicato, e possono usufruire del servizio Info Start, che permette di ricevere aggiornamenti istantanei su eventuali interruzioni delle linee, variazioni temporanee dei percorsi dovute ad imprevisti e tante altre notizie. Che stai aspettando?

Scegli il tuo username, inserisci una password ed entra nel mondo Start!

- Username
- Email
- Password (almeno 8 caratteri)
- Conferma password

## Area Riservata Start&You

Username o Email
Password
Ricordami Password dimenticata?

Non hai ancora un account?
Scopri i vantaggi del mondo Start

Registrati
Adesso